@@ -21,7 +21,7 @@ class Category:
     inputs: Sequence[Type]
     default_op: str
     default_values : Sequence[float]
-    output: str = "image"  # or labels
+    output: str = "image"  # or labels or dataframe
     # categories
     include: Sequence[str] = field(default_factory=tuple)
     exclude: Sequence[str] = field(default_factory=tuple)
@@ -30,6 +30,7 @@ class Category:
     blending : str = "translucent"
     tool_tip : str = ""
     tools_menu : str = None
+    auto_call : bool = True
 
 
 CATEGORIES = {
@@ -147,7 +148,7 @@ CATEGORIES = {
         exclude=("combine",),
         color_map="turbo",
         blending="translucent",
-        tools_menu="Measurement",
+        tools_menu="None",
     ),
     "Measure labeled image": Category(
         name="Measure labeled image",
@@ -159,18 +160,20 @@ CATEGORIES = {
         exclude=("label comparison",),
         color_map="turbo",
         blending="translucent",
-        tools_menu="Measurement",
+        tools_menu="None",
     ),
     "Compare label images": Category(
         name="Compare label images",
-        description="Measure and visualize overlap and \nnonzero pixel count/ratio of labeled \nobjects in two label images.",
+        description="Measure and visualize differences \nof labeled objects in two label images.",
         inputs=(LabelsInput, LabelsInput),
+        output="image",
         default_op="label_overlap_count_map (clesperanto)",
         default_values=[],
         include=("combine","label measurement", "map", "label comparison",),
+        exclude=(),
         color_map="turbo",
         blending="translucent",
-        tools_menu="Measurement",
+        tools_menu="None",
     ),
     "Label neighbor filters": Category(
         name="Label neighbor filters",
@@ -192,7 +195,7 @@ CATEGORIES = {
         default_values=[1, 100],
         include=('label processing', 'combine'),
         exclude=("neighbor",),
-        tools_menu="Label filters",
+        tools_menu="Segmentation post-processing",
     ),
     "Mesh": Category(
         name="Mesh",
@@ -205,7 +208,17 @@ CATEGORIES = {
         blending="additive",
         tools_menu="Visualization",
     ),
-
+    "Measurement": Category(
+        name="Measurement",
+        description="Measure features and show results in a table.",
+        inputs=(ImageInput, LabelsInput),
+        output="dataframe",
+        default_op="Regionprops (nsr)",
+        default_values=[],
+        include=(),
+        tools_menu="Measurement",
+        auto_call=False
+    ),
 }
 
 
@@ -280,6 +293,8 @@ def collect_from_tools_menu_if_installed():
         print("Assistant skips harvesting tools menu as it's not installed.")
         return {}
 
+    import pandas
+
     allowed_types = ["napari.types.LabelsData", "napari.types.ImageData", "int", "float", "str", "bool",
                      "napari.viewer.Viewer", "napari.Viewer"]
     allowed_types = allowed_types + ["<class '" + t + "'>" for t in allowed_types]
@@ -304,7 +319,9 @@ def collect_from_tools_menu_if_installed():
                 continue
 
             # return type must be image or label_image
-            if sig.return_annotation not in [napari.types.LabelsData, "napari.types.LabelsData", napari.types.ImageData, "napari.types.ImageData"]:
+            if sig.return_annotation not in [napari.types.LabelsData, "napari.types.LabelsData",
+                                             napari.types.ImageData, "napari.types.ImageData",
+                                             pandas.DataFrame, "pandas.DataFrame"]:
                 continue
 
             result[k] = f
@@ -413,7 +430,11 @@ def operations_in_menu(category, search_string: str = None):
 
         # only keep the function in this category if it matches
         if num_image_parameters_in_category == num_image_parameters_in_function:
-            result.append(name)
+            if category.name == "Measurement":
+                if str(sig.return_annotation) == "pandas.DataFrame":
+                    result.append(name)
+            else:
+                result.append(name)
 
     return result
 
